@@ -3,4 +3,4 @@ from .index import Index
 from .interpolating_index import InterpolatingIndex
 from .interval_index import IntervalIndex
 from .multi_index import MultiIndex
-from .types import Interval
+from ..types import Interval
